( cd opt/kde/share/doc/HTML/ca/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/krfb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kpercentage ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmail ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kmoon ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kompare ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kweather ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kioslave ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/keduca ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kspell ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
( cd opt/kde/share/doc/HTML/ca/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ca/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
